package io.invertase.firebase.admob;

import android.content.Context;
import android.util.Log;

import androidx.annotation.NonNull;

import com.facebook.react.views.view.ReactViewGroup;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.AdView;
import com.google.android.gms.ads.LoadAdError;

public class AdMobView extends ReactViewGroup {
	private static final String TAG = "AD_MOB_VIEW";
	private Boolean requested = false;
	private AdRequest request;
	private AdSize size;
	private String unitId;
	private AdView adView;
	private AdMobBannerListener listener;

	public AdMobView(Context context) {
		super(context);
	}

	public void addBannerView(){
		Log.d(TAG, "add new view to " + getId() );
		adView = new AdView(getContext());

		adView.setAdListener(new AdListener() {
			@Override
			public void onAdClosed() {
				super.onAdClosed();
				Log.d(TAG, "ad closed " + getId() );
				if(listener != null){
					listener.onAdClosed(AdMobView.this);
				}
			}

			@Override
			public void onAdFailedToLoad(@NonNull LoadAdError loadAdError) {
				super.onAdFailedToLoad(loadAdError);
				Log.d(TAG, "ad failed " + getId() + " with error: " + loadAdError.getMessage() );
				if(listener != null){
					listener.onAdFailedToLoad(AdMobView.this, loadAdError);
				}
			}

			@Override
			public void onAdOpened() {
				super.onAdOpened();
				Log.d(TAG, "ad opened " + getId() );
				if(listener != null){
					listener.onAdOpened(AdMobView.this);
				}
			}

			@Override
			public void onAdLoaded() {
				super.onAdLoaded();
				Log.d(TAG, "ad loaded " + getId() );
				if(listener != null){
					listener.onAdLoaded(AdMobView.this);
				}
			}

			@Override
			public void onAdClicked() {
				super.onAdClicked();
				Log.d(TAG, "ad clicked " + getId() );
				if(listener != null){
					listener.onAdClicked(AdMobView.this);
				}
			}

			@Override
			public void onAdImpression() {
				super.onAdImpression();
				Log.d(TAG, "ad impression " + getId() );
				if(listener != null){
					listener.onAdImpression(AdMobView.this);
				}
			}
		});
		addView(adView);
	}

	public void addListener(AdMobBannerListener listener){
		this.listener = listener;
	}

	public AdView getAdView(){
		return adView;
	}

	public void setRequest(AdRequest request) {
		this.request = request;
	}

	public AdSize getSize() {
		return size;
	}

	public void setSize(AdSize size) {
		this.size = size;
	}

	public void setUnitId(String unitId) {
		this.unitId = unitId;
	}

	public void makeRequest() {
		if(size == null || unitId == null || request == null){
			return;
		}

		if (requested) {
			reset();
		}

		Log.d(TAG, "make new request " + getId() );
		Log.d(TAG, "unitId " + unitId );
		Log.d(TAG, "size " + size.toString() );
		adView.setAdUnitId(unitId);
		adView.setAdSize(size);
		adView.loadAd(request);

		requested = true;
	}

	private void reset() {
		Log.d(TAG, "reset view " + getId());
		removeViewAt(0);
		if (adView != null) {
			adView.destroy();
		}
		addBannerView();
	}
}
