package io.invertase.firebase.admob;

import android.app.Activity;
import android.content.Context;
import android.util.Log;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.modules.core.DeviceEventManagerModule;

import java.util.HashMap;
import java.util.Map;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

public class FirebaseModule extends ReactContextBaseJavaModule {
	private String moduleName;

	public FirebaseModule(ReactApplicationContext reactContext, String moduleName
	) {
		super(reactContext);
		this.moduleName = moduleName;
	}

	public static void rejectPromiseWithCodeAndMessage(Promise promise, String code, String message) {
		WritableMap userInfoMap = Arguments.createMap();
		userInfoMap.putString("code", code);
		userInfoMap.putString("message", message);
		promise.reject(code, message, userInfoMap);
	}

	@Override
	public void initialize() {
		super.initialize();
	}

	public ReactContext getContext() {
		return getReactApplicationContext();
	}

	public Context getApplicationContext() {
		return getReactApplicationContext().getApplicationContext();
	}

	public Activity getActivity() {
		return getCurrentActivity();
	}

	@Nonnull
	@Override
	public String getName() {
		return "RNFB" + moduleName + "Module";
	}

	@Override
	public Map<String, Object> getConstants() {
		return new HashMap<>();
	}


	protected void sendAdEvent(String event, int requestId, String type, String adUnitId, @Nullable WritableMap error) {
		WritableMap eventBody = Arguments.createMap();
		eventBody.putString("type", type);

		if (error != null) {
			eventBody.putMap("error", error);
		}

		emit(new ReactNativeFirebaseAdMobEvent(event, requestId, adUnitId, eventBody));
	}

	protected void sendAdEvent(String event, int requestId, String type, String adUnitId, @Nullable WritableMap error, @Nullable WritableMap data) {
		WritableMap eventBody = Arguments.createMap();
		eventBody.putString("type", type);

		if (error != null) {
			eventBody.putMap("error", error);
		}
		if (data != null) {
			eventBody.putMap("data", data);
		}

		emit(new ReactNativeFirebaseAdMobEvent(event, requestId, adUnitId, eventBody));
	}

	protected boolean emit(final NativeEvent event) {
		if (getReactApplicationContext() == null || !getReactApplicationContext().hasActiveCatalystInstance()) {
			return false;
		}

		try {
			getReactApplicationContext().getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class
			).emit("rnfb_" + event.getEventName(), event.getEventBody());
		} catch (Exception e) {
			Log.wtf("RNFB_EMITTER", "Error sending Event " + event.getEventName(), e);
			return false;
		}

		return true;
	}
}
