import React, { useState, useEffect } from "react";
import PropTypes from "prop-types";
import { requireNativeComponent } from "react-native";
import { isFunction } from "../common";
import NativeFirebaseError from "../internal/NativeFirebaseError";
import BannerAdSize from "../BannerAdSize";
import validateAdRequestOptions from "../validateAdRequestOptions";
const initialState = [0, 0];
const sizeRegex = /([0-9]+)x([0-9]+)/;
function BannerAd({
  unitId,
  size,
  requestOptions,
  ...props
}) {
  const [dimensions, setDimensions] = useState(initialState);
  useEffect(() => {
    if (!unitId) {
      throw new Error("BannerAd: 'unitId' expected a valid string unit ID.");
    }
  }, [unitId]);
  useEffect(() => {
    if (!BannerAdSize[size] && !sizeRegex.test(size)) {
      throw new Error("BannerAd: 'size' expected a valid BannerAdSize or custom size string.");
    }
  }, [size]);
  useEffect(() => {
    if (!BannerAdSize[size] && !sizeRegex.test(size)) {
      throw new Error("BannerAd: 'size' expected a valid BannerAdSize or custom size string.");
    }
  }, [size]);
  const parsedRequestOptions = JSON.stringify(requestOptions);
  useEffect(() => {
    if (requestOptions) {
      try {
        validateAdRequestOptions(requestOptions);
      } catch (e) {
        throw new Error(`BannerAd: ${e.message}`);
      }
    }
  }, [parsedRequestOptions]);
  function onNativeEvent({
    nativeEvent
  }) {
    const {
      width,
      height,
      type
    } = nativeEvent;
    if (type !== "onSizeChanged" && isFunction(props[type])) {
      let eventPayload;
      if (type === "onAdFailedToLoad") {
        eventPayload = NativeFirebaseError.fromEvent(nativeEvent, "admob");
      }
      props[type](eventPayload);
    }
    if (width && height && size !== "FLUID") {
      setDimensions([width, height]);
    }
  }
  let style;
  if (size === "FLUID") {
    // eslint-disable-next-line react/prop-types
    ({
      style
    } = props);
  } else {
    style = {
      width: dimensions[0],
      height: dimensions[1]
    };
  }
  return /*#__PURE__*/React.createElement(ReactNativeFirebaseAdMobBannerView, {
    size: size,
    style: style,
    unitId: unitId,
    request: validateAdRequestOptions(requestOptions),
    onNativeEvent: onNativeEvent
  });
}
const ReactNativeFirebaseAdMobBannerView = requireNativeComponent("ReactNativeFirebaseAdMobBannerView", BannerAd);
BannerAd.propTypes = {
  unitId: PropTypes.string.isRequired,
  size: PropTypes.string.isRequired,
  requestOptions: PropTypes.object,
  onAdLoaded: PropTypes.func,
  onAdFailedToLoad: PropTypes.func,
  onAdOpened: PropTypes.func,
  onAdClosed: PropTypes.func,
  onAdLeftApplication: PropTypes.func
};
export default BannerAd;
//# sourceMappingURL=BannerAd.js.map