import { NativeModules } from "react-native";
import { isFunction, isString } from "../common";
import validateAdRequestOptions from "../validateAdRequestOptions";
import validateAdShowOptions from "../validateAdShowOptions";
import MobileAd from "./MobileAd";
let _interstitialRequest = 0;
const AdMobInterstitialModule = NativeModules.RNFBAdMobInterstitialModule;
export default class InterstitialAd extends MobileAd {
  static createForAdRequest(adUnitId, requestOptions) {
    if (!isString(adUnitId)) {
      throw new Error("ADMOB -> InterstitialAd.createForAdRequest(*) 'adUnitId' expected an string value.");
    }
    let options = {};
    try {
      options = validateAdRequestOptions(requestOptions);
    } catch (e) {
      throw new Error(`ADMOB -> InterstitialAd.createForAdRequest(_, *) ${e.message}.`);
    }
    _interstitialRequest += 1;
    const requestId = _interstitialRequest;
    return new InterstitialAd("interstitial", requestId, adUnitId, options, AdMobInterstitialModule, "admob_interstitial_event");
  }
  load() {
    // Prevent multiple load calls
    if (this._loaded || this._isLoadCalled) {
      return;
    }
    this._isLoadCalled = true;
    AdMobInterstitialModule.interstitialLoad(this._requestId, this._adUnitId, this._requestOptions);
  }
  onAdEvent(handler) {
    if (!isFunction(handler)) {
      throw new Error("ADMOB -> InterstitialAd.onAdEvent(*) 'handler' expected a function.");
    }
    return this._setAdEventHandler(handler);
  }
  show(showOptions) {
    if (!this._loaded) {
      throw new Error("ADMOB -> InterstitialAd.show() The requested InterstitialAd has not loaded and could not be shown.");
    }
    let options;
    try {
      options = validateAdShowOptions(showOptions);
    } catch (e) {
      throw new Error(`ADMOB -> InterstitialAd.show(*) ${e.message}.`);
    }
    return AdMobInterstitialModule.interstitialShow(this._requestId, options);
  }
}
//# sourceMappingURL=InterstitialAd.js.map