import { NativeEventEmitter } from "react-native";
import NativeError from "../internal/NativeFirebaseError";
import AdEventType from "../AdEventType";
import RewardedAdEventType from "../RewardedAdEventType";
export default class MobileAd {
  constructor(type, requestId, adUnitId, requestOptions, NativeModule, event) {
    this._type = type;
    this._requestId = requestId;
    this._adUnitId = adUnitId;
    this._requestOptions = requestOptions;
    this._loaded = false;
    this._isLoadCalled = false;
    this._onAdEventHandler = null;
    this._emitter = new NativeEventEmitter(NativeModule);
    this._nativeListener = this._emitter.addListener(`rnfb_${event}`, this._handleAdEvent.bind(this));
  }
  _handleAdEvent(event) {
    const {
      body,
      requestId
    } = event;
    const {
      type,
      error,
      data
    } = body;
    if (requestId !== this._requestId) {
      return;
    }
    if (type === AdEventType.LOADED || type === RewardedAdEventType.LOADED) {
      this._loaded = true;
    }
    if (type === AdEventType.CLOSED || type === RewardedAdEventType.CLOSED) {
      this._loaded = false;
      this._isLoadCalled = false;
    }
    if (this._onAdEventHandler) {
      let nativeError;
      if (error) {
        nativeError = NativeError.fromEvent(error, "admob");
      }
      this._onAdEventHandler(type, nativeError, data);
    }
  }
  _setAdEventHandler(handler) {
    this._onAdEventHandler = handler;
    return () => this._onAdEventHandler = null;
  }
  get adUnitId() {
    return this._adUnitId;
  }
  get loaded() {
    return this._loaded;
  }
}
//# sourceMappingURL=MobileAd.js.map