import { NativeModules } from "react-native";
import { isFunction, isString } from "../common";
import validateAdRequestOptions from "../validateAdRequestOptions";
import validateAdShowOptions from "../validateAdShowOptions";
import MobileAd from "./MobileAd";
let _rewardedRequest = 0;
const AdMobRewardedModule = NativeModules.RNFBAdMobRewardedModule;
export default class RewardedAd extends MobileAd {
  static createForAdRequest(adUnitId, requestOptions) {
    if (!isString(adUnitId)) {
      throw new Error("ADMOB -> RewardedAd.createForAdRequest(*) 'adUnitId' expected an string value.");
    }
    let options = {};
    try {
      options = validateAdRequestOptions(requestOptions);
    } catch (e) {
      throw new Error(`ADMOB -> RewardedAd.createForAdRequest(_, *) ${e.message}.`);
    }
    _rewardedRequest += 1;
    const requestId = _rewardedRequest;
    return new RewardedAd("rewarded", requestId, adUnitId, options, AdMobRewardedModule, "admob_rewarded_event");
  }
  load() {
    // Prevent multiple load calls
    if (this._loaded || this._isLoadCalled) {
      return;
    }
    this._isLoadCalled = true;
    AdMobRewardedModule.rewardedLoad(this._requestId, this._adUnitId, this._requestOptions);
  }
  onAdEvent(handler) {
    if (!isFunction(handler)) {
      throw new Error("ADMOB -> RewardedAd.onAdEvent(*) 'handler' expected a function.");
    }
    return this._setAdEventHandler(handler);
  }
  show(showOptions) {
    if (!this._loaded) {
      throw new Error("ADMOB -> RewardedAd.show() The requested RewardedAd has not loaded and could not be shown.");
    }
    let options;
    try {
      options = validateAdShowOptions(showOptions);
    } catch (e) {
      throw new Error(`ADMOB -> RewardedAd.show(*) ${e.message}.`);
    }
    return AdMobRewardedModule.rewardedShow(this._requestId, this._adUnitId, options);
  }
}
//# sourceMappingURL=RewardedAd.js.map