export default class NativeFirebaseError extends Error {
  static fromEvent(errorEvent, namespace, stack) {
    return new NativeFirebaseError({
      userInfo: errorEvent
    }, stack || new Error().stack, namespace);
  }
  constructor(nativeError, jsStack, namespace) {
    super();
    const {
      userInfo
    } = nativeError;
    Object.defineProperty(this, "namespace", {
      enumerable: false,
      value: namespace
    });
    Object.defineProperty(this, "code", {
      enumerable: false,
      value: `${this.namespace}/${userInfo.code || "unknown"}`
    });
    Object.defineProperty(this, "message", {
      enumerable: false,
      value: `[${this.code}] ${userInfo.message || nativeError.message}`
    });
    Object.defineProperty(this, "jsStack", {
      enumerable: false,
      value: jsStack
    });
    Object.defineProperty(this, "userInfo", {
      enumerable: false,
      value: userInfo
    });
    Object.defineProperty(this, "nativeErrorCode", {
      enumerable: false,
      value: userInfo.nativeErrorCode || null
    });
    Object.defineProperty(this, "nativeErrorMessage", {
      enumerable: false,
      value: userInfo.nativeErrorMessage || null
    });
    this.stack = NativeFirebaseError.getStackWithMessage(`NativeFirebaseError: ${this.message}`, this.jsStack);

    // Unused
    // this.nativeStackIOS = nativeError.nativeStackIOS;
    // this.nativeStackAndroid = nativeError.nativeStackAndroid;
  }

  /**
   * Build a stack trace that includes JS stack prior to calling the native method.
   *
   * @returns {string}
   */
  static getStackWithMessage(message, jsStack) {
    return [message, ...jsStack.split("\n").slice(2, 13)].join("\n");
  }
}
//# sourceMappingURL=NativeFirebaseError.js.map