import { hasOwnProperty, isBoolean, isObject } from "./common";
import MaxAdContentRating from "./MaxAdContentRating";
export default function validateAdRequestConfiguration(requestConfiguration) {
  const out = {};
  if (!isObject(requestConfiguration)) {
    throw new Error("'requestConfiguration' expected an object value");
  }
  if (requestConfiguration.maxAdContentRating) {
    if (requestConfiguration.maxAdContentRating !== MaxAdContentRating.G && requestConfiguration.maxAdContentRating !== MaxAdContentRating.PG && requestConfiguration.maxAdContentRating !== MaxAdContentRating.T && requestConfiguration.maxAdContentRating !== MaxAdContentRating.MA) {
      throw new Error("'requestConfiguration.maxAdContentRating' expected on of MaxAdContentRating.G, MaxAdContentRating.PG, MaxAdContentRating.T or MaxAdContentRating.MA");
    }
    out.maxAdContentRating = requestConfiguration.maxAdContentRating;
  }
  if (hasOwnProperty(requestConfiguration, "tagForChildDirectedTreatment")) {
    if (!isBoolean(requestConfiguration.tagForChildDirectedTreatment)) {
      throw new Error("'requestConfiguration.tagForChildDirectedTreatment' expected a boolean value");
    }
    out.tagForChildDirectedTreatment = requestConfiguration.tagForChildDirectedTreatment;
  }
  if (hasOwnProperty(requestConfiguration, "tagForUnderAgeOfConsent")) {
    if (!isBoolean(requestConfiguration.tagForUnderAgeOfConsent)) {
      throw new Error("'requestConfiguration.tagForUnderAgeOfConsent' expected a boolean value");
    }
    out.tagForUnderAgeOfConsent = requestConfiguration.tagForUnderAgeOfConsent;
  }
  return out;
}
//# sourceMappingURL=validateAdRequestConfiguration.js.map